@@ -1,4 +1,10 @@
 #!/bin/bash
+POTFILE="new/gespeaker.pot"
+if ! [ -d new ]
+then
+  mkdir new
+fi
+
 if [ -f ../data/ui/*.glade.h ]
 then
   rm ../data/ui/*.glade.h
@@ -6,10 +12,10 @@ fi
 intltool-extract --type=gettext/glade ../data/ui/gespeaker.glade
 intltool-extract --type=gettext/glade ../data/ui/preferences.glade
 
-if ! [ -f gespeaker.pot ]
+if ! [ -f $POTFILE ]
 then
-  touch gespeaker.pot
+  touch $POTFILE
 fi
-xgettext --language=Python --keyword=_ --keyword=N_ --output gespeaker.pot --join-existing ../data/ui/*.glade.h ../src/*.py
+xgettext --language=Python --keyword=_ --keyword=N_ --output $POTFILE ../data/ui/*.glade.h ../src/*.py
 rm ../data/ui/*.glade.h
 read
